.. _csrf_module:

:mod:`pyramid.csrf`
-------------------

.. automodule:: pyramid.csrf

  .. autoclass:: LegacySessionCSRFStoragePolicy
     :members:

  .. autoclass:: SessionCSRFStoragePolicy
     :members:

  .. autoclass:: CookieCSRFStoragePolicy
     :members:

  .. autofunction:: get_csrf_token

  .. autofunction:: new_csrf_token

  .. autofunction:: check_csrf_origin

  .. autofunction:: check_csrf_token
